import * as React from "react";
import PropTypes from "prop-types";
import AppBar from "@mui/material/AppBar";
import Toolbar from "@mui/material/Toolbar";
import Typography from "@mui/material/Typography";
import useScrollTrigger from "@mui/material/useScrollTrigger";
import Slide from "@mui/material/Slide";
import {
  useTheme,
  useMediaQuery,
} from "@material-ui/core";

import Drawer from "./Drawer";
import { NavLink } from "./styled";
import { color } from "@mui/system";

function HideOnScroll(props) {
  const { children, window } = props;
  const trigger = useScrollTrigger({
    target: window ? window() : undefined,
  });

  return (
    <Slide appear={false} direction="down" in={!trigger}>
      {children}
    </Slide>
  );
}

HideOnScroll.propTypes = {
  children: PropTypes.element.isRequired,
  window: PropTypes.func,
};

function Navbar(props) {
  const theme = useTheme();
  const isMobile = useMediaQuery(theme.breakpoints.down("sm"));

  return (
    <HideOnScroll {...props}>
      <AppBar 
        sx={{ 
          backgroundColor: "#074B6B !important", 
          px: {
            lg: 8,
          },
          color: {
            md: "#ffffff !important",
            sm: "#404040 !important"
          }
        }}>
        <Toolbar>
          <Typography 
            variant="h6"
            component="div"
            sx={{ flexGrow: 1 }}
          >
            Logo
          </Typography>
          {isMobile ? (
            <Drawer />
          ) : (
            <>
              <NavLink href="#" edge="end" >Productos</NavLink>
              <NavLink href="#">Quiénes somos</NavLink>
              <NavLink href="#">Blog</NavLink>
              <NavLink href="#">Clientes</NavLink>
              <NavLink href="#">Contáctanos</NavLink>
            </>
          )}
        </Toolbar>
      </AppBar>
    </HideOnScroll>
  );
};

export default Navbar;
